==> dde-shell_1.0.10.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>main</name>
    <message>
        <location filename="../package/main.qml" line="162"/>
        <source>Indicator Style</source>
        <translation>Indicatorstijl</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="164"/>
        <source>Fashion Mode</source>
        <translation>Moderne modus</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="169"/>
        <source>Efficient Mode</source>
        <translation>Efficiënte modus</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="175"/>
        <source>Alignment</source>
        <translation>Uitlijning</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="206"/>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="194"/>
        <source>Position</source>
        <translation>Locatie</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="179"/>
        <source>Align Left</source>
        <translation>Links uitlijnen</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="181"/>
        <source>Align Top</source>
        <translation>Bovenaan uitlijnen</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="188"/>
        <source>Align Center</source>
        <translation>Rechts uitlijnen</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="196"/>
        <source>Top</source>
        <translation>Bovenaan</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="201"/>
        <source>Bottom</source>
        <translation>Onderaan</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="211"/>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="217"/>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="219"/>
        <source>Keep Shown</source>
        <translation>Altijd tonen</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="224"/>
        <source>Keep Hidden</source>
        <translation>Altijd verbergen</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="230"/>
        <source>Smart Hide</source>
        <translation>Slim verbergen</translation>
    </message>
    <message>
        <location filename="../package/main.qml" line="237"/>
        <source>Dock Settings</source>
        <translation>Dockinstellingen</translation>
    </message>
</context>
</TS>

==> dde-shell_1.99.36.tar.xz: BUILD/panels/dock/translations/org.deepin.ds.dock_nl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="nl">
<context>
    <name>main</name>
    <message>
        <source>Indicator Style</source>
        <translation>Indicatorstijl</translation>
    </message>
    <message>
        <source>Fashion Mode</source>
        <translation>Moderne modus</translation>
    </message>
    <message>
        <source>Efficient Mode</source>
        <translation>Efficiënte modus</translation>
    </message>
    <message>
        <source>Classic Mode</source>
        <translation>Klassieke modus</translation>
    </message>
    <message>
        <source>Centered Mode</source>
        <translation>Gecentreerde modus</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <source>Position</source>
        <translation>Locatie</translation>
    </message>
    <message>
        <source>Mode</source>
        <translation>Modus</translation>
    </message>
    <message>
        <source>Top</source>
        <translation>Bovenaan</translation>
    </message>
    <message>
        <source>Bottom</source>
        <translation>Onderaan</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <source>Status</source>
        <translation>Status</translation>
    </message>
    <message>
        <source>Keep Shown</source>
        <translation>Altijd tonen</translation>
    </message>
    <message>
        <source>Keep Hidden</source>
        <translation>Altijd verbergen</translation>
    </message>
    <message>
        <source>Smart Hide</source>
        <translation>Slim verbergen</translation>
    </message>
    <message>
        <source>Dock Settings</source>
        <translation>Dockinstellingen</translation>
    </message>
</context>
</TS>
